==> 0.4.1.tar.gz: lib/src/custom/editable_label.dart <==
part of tags;

final Tag editableLabel = createTag((_) => new EditableLabel());

class EditableLabel extends HtmlElement {
 
  static const TAG = 'editable-label';
 
  ShadowRoot _shadow;
  LabelElement _label;
  TextInputElement _textInput;
  
  String _lastText;
  
  final _onTextChange = new StreamController<String>.broadcast();
  Stream<String> get onTextChange => _onTextChange.stream;
  
  String 
    get text => _label.text;
    set text(String t) {
      if (_textInput.value != t) {
        _textInput.value = t;
      }
      if (_label.text != t) {
        _label.text = t;
        _onTextChange.add(t);
      }
    }
  
  factory EditableLabel() => new Element.tag(TAG);
  
  EditableLabel.created() : super.created() {        
    children(this, () {
      _shadow = shadow(() {
        _label = label();
      })
      ..applyAuthorStyles = true;
    });
    
    _textInput = new InputElement()
    ..onBlur.listen((_) {      
      this.text = _lastText;
      _shadow.children[0] = _label;
    })
    ..onDoubleClick.listen((Event ev) {
      ev.stopPropagation();      
    })
    ..onKeyUp.listen((KeyboardEvent ev) {
      if (ev.keyCode == KeyCode.ESC) {        
        _shadow.children[0] = _label;
      } else if (ev.keyCode == KeyCode.ENTER) {
        this.text = _textInput.value;
        _lastText = this.text;
        _shadow.children[0] = _label;
      }
    })
    ..type = 'text';
  }
  
  void beginEdit() {
    _lastText = this.text;
    _shadow.children[0] = _textInput;
    _textInput.focus();
  }
}

==> 0.4.3.tar.gz: lib/src/custom/editable_label.dart <==
part of tags;

final Tag editableLabel = createTag((_) => new EditableLabel());

class EditableLabel extends HtmlElement {
 
  static const TAG = 'editable-label';
 
  ShadowRoot _shadow;
  LabelElement _label;
  TextInputElement _textInput;
  
  String _text;
  String _lastText;
  
  Function displayFilter;
  
  final _onTextChange = new StreamController<String>.broadcast();
  Stream<String> get onTextChange => _onTextChange.stream;
  
  final _onEndEdit = new StreamController<Null>.broadcast();
  Stream<Null> get onEndEdit => _onEndEdit.stream;
  
  String 
    get text => _text;
    set text(String t) {
      if (_textInput.value != t) {
        _textInput.value = t;
      }
      String displayText = t;
      if (displayFilter != null) {
        displayText = displayFilter(t);
      }
      if (_label.text != displayText) {
        _label.text = displayText;
      }
      if (_text != t) {
        _text = t;
        _onTextChange.add(t);
      }
    }  
  
  factory EditableLabel() => new Element.tag(TAG);
  
  EditableLabel.created() : super.created() {        
    children(this, () {
      _shadow = shadow(() {
        _label = label();
      })
      ..applyAuthorStyles = true;
    });
    
    _textInput = new InputElement()
    ..onBlur.listen((_) {      
      this.text = _lastText;
      _shadow.children[0] = _label;
      _onEndEdit.add(null);
    })
    ..onDoubleClick.listen((Event ev) {
      ev.stopPropagation();      
    })
    ..onKeyUp.listen((KeyboardEvent ev) {
      if (ev.keyCode == KeyCode.ESC) {        
        _shadow.children[0] = _label;
        _onEndEdit.add(null);
      } else if (ev.keyCode == KeyCode.ENTER) {
        this.text = _textInput.value;
        _lastText = this.text;
        _shadow.children[0] = _label;
        _onEndEdit.add(null);
      }
    })
    ..type = 'text';
  }
  
  void beginEdit() {
    _lastText = this.text;
    _shadow.children[0] = _textInput;
    _textInput.focus();
  }
}
